==> hboard-1.0-rc2.tar.gz: hboard/config.php <==
<?php

/* EtchiBoard Version 1.0
     config.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/
include ("lib/admin.inc"); //  ȯ漳
include ("lib/headfoot.inc"); //  ȯ漳
include ("lib/message.inc"); // ޽ function

 if($HTTP_COOKIE_VARS["hboard_admin_login"] != $admin_data[passwd]) {
 //  Ű  
  PrintMessage(" Ű ã  ϴ.", "error");
 }

 else {
 /* ȯ   ֱ~ */
?>

<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<title>EtchiBoard ȯ  </title>
<meta http-equiv="content-type" content="text/html; charset=ks_c_5601-1987">
</head>
<body bgcolor="white" link="black" vlink="black">

<script language="JavaScript" type="">
function submit_admin() {
 if(document.configform.admin_pass.value != document.configform.admin_pass_confirm.value) {
  alert("Էµ  йȣ   ġ ʽϴ.");
  document.configform.admin_pass_confirm.focus();
 }
 else if(document.configform.fileup_max.value == "") {
  alert("ִ ε ũ⸦ ּ.");
  document.configform.fileup_max.focus();
 }
 else{
  document.configform.submit();
 }
}

function show_sysinfo() {
<?php
// ý    mysql  ܾɴϴ.
$dbconnect = mysql_connect($hostname, $username, $dbpass);
 mysql_select_db($dbname);
$result = mysql_fetch_array(mysql_query("select version()", $dbconnect));
$mysql_version = $result[0];
$result = mysql_fetch_array(mysql_query("select user()", $dbconnect));
$mysql_user = $result[0];

//  ̺κ ʿѰ?  ϸ Ҹ . [.... ־ ڵ]
if(!$_ENV["SERVER_SOFTWARE"]) $server_api = $SERVER_SOFTWARE;
else $server_api = $_ENV["SERVER_SOFTWARE"];

$server_hostname = $_SERVER["HTTP_HOST"];
$php_version = phpversion();

?>
 var server_api = "<?=$server_api?>";
 var server_hostname = "<?=$server_hostname?>";
 var php_version = "<?=$php_version?>";
 var mysql_version = "<?=$mysql_version?>";
 var mysql_user = "<?=$mysql_user?>";

<?php
// mysql  ݱ
mysql_close($dbconnect);
?>
 alert ('Server: ' + server_api + '\nHostname: ' + server_hostname + '\nPHP Version: ' + php_version + '\nMySQL Version: ' + mysql_version + ' (' + mysql_user + ')');
}

</script>

<form name="configform" method="post" action="config_ok.php">
 <input type="hidden" name="from" value="<?=$from?>">

<table align="center" border="1" cellspacing="0" width="660" bordercolordark="white" bordercolorlight="black">
    <tr>
        <td width="506" bgcolor="#EAEAEA"><P><SPAN style="FONT-SIZE: 9pt"><B><FONT color=#676767>&nbsp;EtchiBoard ȯ 
             </FONT></B></SPAN></P></td>
        <td width="144" bgcolor="#EAEAEA">
            <p align="center"><span style="font-size:9pt;"><a href="uninstall.php"><font color="#990000"><b>[ġ 
                ]</b></font></a> <a href="javascript:window.close()">[â 
            ݱ</a>]</span></p>
        </td>
    </tr>
    <tr>
        <td width="654" colspan="2">
            <table align="center" width="657">

<TR><TD width="146" height=79 bgcolor="#F4F4F4">
<P align=center><SPAN style="FONT-SIZE: 9pt"><FONT color=black> 
йȣ</FONT></SPAN></P></TD>
<TD width="501" height=79 bgcolor="#FAFAFA">
<P><SPAN style="FONT-SIZE: 9pt"><font color="#003399">-  йȣ Խù //,  
,  ε忡 ˴ϴ.<br>- нǵǰų  ʰ  ּ.<BR></font><FONT color=black> йȣ)
&nbsp;<INPUT type=password maxLength=30 size=10 value="" name="admin_pass">&nbsp;ȮԷ) <INPUT type=password maxLength=30 size=10 value="" name="admin_pass_confirm"></FONT><FONT color="#990000"> (ÿ 
Է)<BR></FONT></SPAN></P></TD></TR>

<TR><TD width="146" height=145 bgcolor="#F4F4F4">
<P align=center><SPAN style="FONT-SIZE: 9pt"><FONT color=black>  
۾<BR>(html ±׷ Է)</FONT></SPAN></P></TD>
<TD width="501" height=145 bgcolor="#FAFAFA">
<P><SPAN style="FONT-SIZE: 9pt"><font color="#003399">- ƹ͵     ܿ ۾&nbsp; 
ʽϴ.<BR></font><FONT color=blue>
<TEXTAREA name="title_text" rows=7 cols="63">
<?=$admin_data[title_text]?>
</TEXTAREA>
</FONT></SPAN></P></TD></TR>


<TR><TD width="146" height=58 bgcolor="#F4F4F4">
<P align=center><FONT color=black><SPAN style="FONT-SIZE: 9pt"> ׸</SPAN></FONT></P></TD>
<TD width="501" height=58 bgcolor="#FAFAFA">
<P><FONT color="#003399"><SPAN style="FONT-SIZE: 9pt">-   ׸ ּҸ ּ. (ٵǽ )</SPAN></FONT><FONT color=blue><SPAN style="FONT-SIZE: 9pt"><INPUT size="64" name="bgimage" value="<?=$admin_data[bgimage]?>" maxlength="255"></SPAN></FONT></P></TD></TR>

<TR><TD width="146" height=23 bgcolor="#F4F4F4">
<P align=center><SPAN style="FONT-SIZE: 9pt"><FONT color=black> 
Խù&nbsp;</FONT></SPAN></P></TD>
<TD width="501" height=23 bgcolor="#FAFAFA">
<P>

<SPAN style="FONT-SIZE: 9pt"><SELECT size=1 name="article_per_page">
<OPTION value="<?=$admin_data[app]?>" selected> : <?=$admin_data[app]?></OPTION>
<OPTION value=1>1</OPTION>
<OPTION value=3>3</OPTION>
<OPTION value=5>5</OPTION>
<OPTION value=7>7</OPTION>
<OPTION value=9>9</OPTION>
<OPTION value=11>11</OPTION>
</SELECT>
</SPAN></P></TD></TR>

<TR><TD width="146" height=43 bgcolor="#F4F4F4">
<P align=center><SPAN style="FONT-SIZE: 9pt"><FONT color=black>Խ 
Ų</FONT></SPAN></P></TD>
<TD width="501" height=43 bgcolor="#FAFAFA">
<P><SPAN style="FONT-SIZE: 9pt"><font color="#003399">- Խ     
ֽϴ.<BR></font>

<SELECT size=1 name="board_skin">
<OPTION value="<?=$admin_data[skin]?>" selected> : <?=$admin_data[skin]?></OPTION>
<?php
if ($handle = opendir('skin/')) {
 while (false !== ($file = readdir($handle))) { 
   if ($file != "." && $file != ".." && $file != "index.html") { 
    echo "<option value='" .$file ."'>" .$file ."</option>\n"; 
   }
 }
closedir($handle); 
}
?>
</SELECT>
</SPAN></P>
</TD></TR>

<TR><TD width="146" height=10 bgcolor="#F4F4F4">
<P align=center><SPAN style="FONT-SIZE: 9pt"><FONT color=black>ִ ε ũ</FONT></SPAN></P></TD>
<TD width="501" height=10 bgcolor="#FAFAFA">
<P><SPAN style="FONT-SIZE: 9pt"><font color="#003399">- εǴ ׸ ũⰡ ʹ Ŭ 츦 Ͽ, 
 δ Դϴ.<BR>- 0 , Ʈ  Ͽ ֽʽÿ.<BR></font><FONT color=black><INPUT 
style="TEXT-ALIGN: center" size=14 value="<?=$admin_data[fileup_max]?>" name="fileup_max">byte(s)</FONT></SPAN></P></TD></TR>

<TR><TD width="146" height=43 bgcolor="#F4F4F4">
<P align=center><FONT color=black><SPAN style="FONT-SIZE: 9pt">HTML ± 
</SPAN></FONT></P></TD>
<TD width="501" height=43 bgcolor="#FAFAFA">
<P><FONT color="#003399"><SPAN style="FONT-SIZE: 9pt">- Ͽ Խù ̳ ǰ߱ ǥ , HTML 
±׸  θ մϴ.<br></SPAN></FONT><SPAN style="FONT-SIZE:9pt">

<?php
 // html 뿩 ¿  checkbox  ٸ..
 if($admin_data[html_tag] == "t") {
  echo "<input type=\"radio\" name=\"use_html\" value=\"yes\" checked>Խù/ǰ߱ۿ HTML ± &nbsp;\n";
  echo "<input type=\"radio\" name=\"use_html\" value=\"no\">HTML ±  </SPAN></P>";
 }
 else {
  echo "<input type=\"radio\" name=\"use_html\" value=\"yes\">Խù/ǰ߱ۿ HTML ± &nbsp;\n";
  echo "<input type=\"radio\" name=\"use_html\" value=\"no\" checked>HTML ±  </SPAN></P>";
 }
?></span>

</TD></TR>

<TR><TD width="146" height=58 bgcolor="#F4F4F4">
<P align=center><FONT color=black><SPAN style="FONT-SIZE: 9pt">Խ  
</SPAN></FONT></P></TD>
<TD width="501" height=58 bgcolor="#FAFAFA">
<P><FONT color="#003399"><SPAN style="FONT-SIZE: 9pt">- Խ ܿ (include) html 
 մϴ.<BR>- body, head  ±״ ⿡    켱 óմϴ.<BR></SPAN></FONT><FONT color=blue><SPAN style="FONT-SIZE: 9pt"><INPUT size="64" name="include_up" value="<?=$admin_data[include_top]?>" maxlength="255"></SPAN></FONT></P></TD></TR>

<TR><TD width="146" height=58 bgcolor="#F4F4F4">
<P align=center><FONT color=black><SPAN style="FONT-SIZE: 9pt">Խ ϴ 
</SPAN></FONT></P></TD>
<TD width="501" height=58 bgcolor="#FAFAFA">
<P><FONT color="#003399"><SPAN style="FONT-SIZE: 9pt">- Խ ϴܿ (include) html 
 մϴ.<BR></SPAN></FONT><FONT color=blue><SPAN style="FONT-SIZE: 9pt"><INPUT size="64" name="include_bt" value="<?=$admin_data[include_bottom]?>" maxlength="255"></SPAN></FONT></P></TD></TR>

<TR><TD width="146" height=58 bgcolor="#F4F4F4">
<P align=center><FONT color=black><SPAN style="FONT-SIZE: 9pt">׸ ũ </SPAN></FONT></P></TD>
<TD width="501" height=58 bgcolor="#FAFAFA">
<P><FONT color="#003399"><SPAN style="FONT-SIZE: 9pt">- ׸ (width)ũⰡ Ʒ ġ  ڵ Ʒ ũ ¡ մϴ.<BR>
- 0 ¡  ʽϴ. ( - ¡ ׸   ֽϴ.)</SPAN></FONT><FONT color=blue><SPAN style="FONT-SIZE: 9pt">
<br>
<INPUT style="TEXT-ALIGN: center" size=14 name="width_max" value="<?=$admin_data[width_max]?>"><font color=black>ȼ ̻  ũ  ġ  (/  )</font></SPAN></FONT></P></TD></TR>

<!--
<TR><TD width="146" height=58 bgcolor="#F4F4F4">
<P align=center><FONT color=black><SPAN style="FONT-SIZE: 9pt">Խù  Ѱġ</SPAN></FONT></P></TD>
<TD width="501" height=58 bgcolor="#FAFAFA">
<P><FONT color="#003399"><SPAN style="FONT-SIZE: 9pt">-  ġ   Խù   մϴ.<BR>
- 0 Դϴ (Խù   մϴ)</SPAN></FONT><FONT color=blue><SPAN style="FONT-SIZE: 9pt">
<br>
<INPUT style="TEXT-ALIGN: center" size=14 value="0" name="article_max" value="<?=$admin_data[article_max]?>" readonly><font color=black> </font></SPAN></FONT></P></TD></TR>
-->

<TR><TD width="146" height=30 bgcolor="#F4F4F4">
<P align=center><FONT color=black><SPAN style="FONT-SIZE: 9pt">ý </SPAN></FONT></P></TD>
<TD width="501" height=30 bgcolor="#FAFAFA">
<P><FONT color="#003399"><SPAN style="FONT-SIZE: 9pt"><a href="javascript:show_sysinfo();">[⸦ ŬϽø  ý  ǥմϴ]</a></SPAN></FONT></P></TD></TR>

</table>
</td></tr>
</table>

<P align=center><INPUT accessKey=s type=button value=" (Alt+S)" name=sendvalue onclick="submit_admin()"> 
<INPUT accessKey=r type=reset value="ٽ ۼ(Alt+R)" name=reset></P>
</form>

</body>
</html>

<?php
 }
?>

==> hboard-1.0.1.tar.gz: hboard/config.php <==
<?php

/* EtchiBoard Version 1.0
     config.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/
include ("lib/admin.inc"); //  ȯ漳
include ("lib/headfoot.inc"); //  ȯ漳
include ("lib/message.inc"); // ޽ function

 if($HTTP_COOKIE_VARS["hboard_admin_login"] != $admin_data[passwd]) {
 //  Ű  
  PrintMessage(" Ű ã  ϴ.", "error");
 }

 else {
 /* ù:   ϱ */

$dbconnect = mysql_connect($hostname, $username, $dbpass);
 mysql_select_db($dbname);
$result = mysql_fetch_array(mysql_query("select version()", $dbconnect));
$mysql_version = $result[0];
$result = mysql_fetch_array(mysql_query("select user()", $dbconnect));
$mysql_user = $result[0];

//  ̺κ ʿѰ?  ϸ Ҹ . [.... ־ ڵ]
if(!$_ENV["SERVER_SOFTWARE"]) $server_api = $SERVER_SOFTWARE;
else $server_api = $_ENV["SERVER_SOFTWARE"];

$server_hostname = $_SERVER["HTTP_HOST"];
$php_version = phpversion();
if($php_version) $php_version_head = substr($php_version, 0, 3);

// Ż縮 PHP    ʿ ɵ鵵 -.- ְ.. ư checked ϰ..
if($admin_data[html_tag] == "t") $html_tag[on] = "checked";
else $html_tag[off] = "checked";

if($admin_data[autolink] == "t") $autolink[on] = "checked";
else $autolink[off] = "checked";

if($php_version > 4.2 || $php_version == "") {
 if($admin_data[backdrum] == "t") $backdrum[on] = "checked";
 else $backdrum[off] = "checked";
}
else {
 // PHP  4.2.0 ̻ ƴ , ߺ Ұ.. 
 $backdrum[on] = "disabled";
 $backdrum[off] = "disabled";
}
mysql_close($dbconnect);

/*   ... */
?>

<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<title>EtchiBoard ȯ  </title>
<meta http-equiv="content-type" content="text/html; charset=ks_c_5601-1987">
</head>
<body bgcolor="white" link="black" vlink="black">

<script language="JavaScript" type="">
function submit_admin() {
 if(document.configform.admin_pass.value != document.configform.admin_pass_confirm.value) {
  alert("Էµ  йȣ   ġ ʽϴ.");
  document.configform.admin_pass_confirm.focus();
 }
 else if(document.configform.fileup_max.value == "") {
  alert("ִ ε ũ⸦ ּ.");
  document.configform.fileup_max.focus();
 }
 else{
  document.configform.submit();
 }
}

function show_sysinfo() {
 var server_api = "<?php echo $server_api?>";
 var server_hostname = "<?php echo $server_hostname?>";
 var php_version = "<?php echo $php_version?>";
 var mysql_version = "<?php echo $mysql_version?>";
 var mysql_user = "<?php echo $mysql_user?>";

 alert ('Server: ' + server_api + '\nHostname: ' + server_hostname + '\nPHP Version: ' + php_version + '\nMySQL Version: ' + mysql_version + ' (' + mysql_user + ')');
}
</script>

<form name="configform" method="post" action="config_ok.php">
 <input type="hidden" name="from" value="<?php echo $from?>">

<table align="center" border="1" cellspacing="0" width="660" bordercolordark="white" bordercolorlight="black">
    <tr>
        <td width="506" bgcolor="#EAEAEA"><P><SPAN style="FONT-SIZE: 9pt"><B><FONT color=#676767>&nbsp;EtchiBoard ȯ 
             </FONT></B></SPAN></P></td>
        <td width="144" bgcolor="#EAEAEA">
            <p align="center"><span style="font-size:9pt;"><a href="uninstall.php"><font color="#990000"><b>[ġ 
                ]</b></font></a> <a href="javascript:window.close()">[â 
            ݱ</a>]</span></p>
        </td>
    </tr>
    <tr>
        <td width="654" colspan="2">
            <table align="center" width="657">

<TR><TD width="146" height=79 bgcolor="#F4F4F4">
<P align=center><SPAN style="FONT-SIZE: 9pt"><FONT color=black> 
йȣ</FONT></SPAN></P></TD>
<TD width="501" height=79 bgcolor="#FAFAFA">
<P><SPAN style="FONT-SIZE: 9pt"><font color="#003399">-  йȣ Խù //,  
,  ε忡 ˴ϴ.<br>- нǵǰų  ʰ  ּ.<BR></font><FONT color=black> йȣ)
&nbsp;<INPUT type=password maxLength=30 size=10 value="" name="admin_pass">&nbsp;ȮԷ) <INPUT type=password maxLength=30 size=10 value="" name="admin_pass_confirm"></FONT><FONT color="#990000"> (ÿ 
Է)<BR></FONT></SPAN></P></TD></TR>

<TR><TD width="146" height=145 bgcolor="#F4F4F4">
<P align=center><SPAN style="FONT-SIZE: 9pt"><FONT color=black>  
۾<BR>(html ±׷ Է)</FONT></SPAN></P></TD>
<TD width="501" height=145 bgcolor="#FAFAFA">
<P><SPAN style="FONT-SIZE: 9pt"><font color="#003399">- ƹ͵     ܿ ۾&nbsp; 
ʽϴ.<BR></font><FONT color=blue>
<TEXTAREA name="title_text" rows=7 cols="63">
<?php echo $admin_data[title_text]?>
</TEXTAREA>
</FONT></SPAN></P></TD></TR>


<TR><TD width="146" height=58 bgcolor="#F4F4F4">
<P align=center><FONT color=black><SPAN style="FONT-SIZE: 9pt"> ׸</SPAN></FONT></P></TD>
<TD width="501" height=58 bgcolor="#FAFAFA">
<P><FONT color="#003399"><SPAN style="FONT-SIZE: 9pt">-   ׸ ּҸ ּ. (ٵǽ )</SPAN></FONT><FONT color=blue><SPAN style="FONT-SIZE: 9pt"><INPUT size="64" name="bgimage" value="<?php echo $admin_data[bgimage]?>" maxlength="255"></SPAN></FONT></P></TD></TR>

<TR><TD width="146" height=23 bgcolor="#F4F4F4">
<P align=center><SPAN style="FONT-SIZE: 9pt"><FONT color=black> 
Խù&nbsp;</FONT></SPAN></P></TD>
<TD width="501" height=23 bgcolor="#FAFAFA">
<P>

<SPAN style="FONT-SIZE: 9pt"><SELECT size=1 name="article_per_page">
<OPTION value="<?php echo $admin_data[app]?>" selected> : <?php echo $admin_data[app]?></OPTION>
<OPTION value=1>1</OPTION>
<OPTION value=3>3</OPTION>
<OPTION value=5>5</OPTION>
<OPTION value=7>7</OPTION>
<OPTION value=9>9</OPTION>
<OPTION value=11>11</OPTION>
</SELECT>
</SPAN></P></TD></TR>

<TR><TD width="146" height=43 bgcolor="#F4F4F4">
<P align=center><SPAN style="FONT-SIZE: 9pt"><FONT color=black>Խ 
Ų</FONT></SPAN></P></TD>
<TD width="501" height=43 bgcolor="#FAFAFA">
<P><SPAN style="FONT-SIZE: 9pt"><font color="#003399">- Խ     
ֽϴ.<BR></font>

<SELECT size=1 name="board_skin">
<OPTION value="<?php echo $admin_data[skin]?>" selected> : <?php echo $admin_data[skin]?></OPTION>
<?php
if ($handle = opendir('skin/')) {
 while (false !== ($file = readdir($handle))) { 
   if ($file != "." && $file != ".." && $file != "index.html") { 
    echo "<option value='" .$file ."'>" .$file ."</option>\n"; 
   }
 }
closedir($handle); 
}
?>
</SELECT>
</SPAN></P>
</TD></TR>

<TR><TD width="146" height=10 bgcolor="#F4F4F4">
<P align=center><SPAN style="FONT-SIZE: 9pt"><FONT color=black>ִ ε ũ</FONT></SPAN></P></TD>
<TD width="501" height=10 bgcolor="#FAFAFA">
<P><SPAN style="FONT-SIZE: 9pt"><font color="#003399">- εǴ ׸ ũⰡ ʹ Ŭ 츦 Ͽ, 
 δ Դϴ.<BR>- 0 , Ʈ  Ͽ ֽʽÿ.<BR></font><FONT color=black><INPUT 
style="TEXT-ALIGN: center" size=14 value="<?php echo $admin_data[fileup_max]?>" name="fileup_max">byte(s)</FONT></SPAN></P></TD></TR>

<TR><TD width="146" height=43 bgcolor="#F4F4F4">
<P align=center><FONT color=black><SPAN style="FONT-SIZE: 9pt">HTML ± 
</SPAN></FONT></P></TD>
<TD width="501" height=43 bgcolor="#FAFAFA">
<P><FONT color="#003399"><SPAN style="FONT-SIZE: 9pt">- Ͽ Խù ̳ ǰ߱ ǥ , HTML 
±׸  θ մϴ.<br></SPAN></FONT><SPAN style="FONT-SIZE:9pt">
<input type="radio" name="use_html" value="t" <?php echo $html_tag[on]?>>Խù/ǰ߱ۿ HTML ± &nbsp;
<input type="radio" name="use_html" value="f" <?php echo $html_tag[off]?>>HTML ±  </SPAN></P>
</span>
</TD></TR>

<TR><TD width="146" height=58 bgcolor="#F4F4F4">
<P align=center><FONT color=black><SPAN style="FONT-SIZE: 9pt">Խ  
</SPAN></FONT></P></TD>
<TD width="501" height=58 bgcolor="#FAFAFA">
<P><FONT color="#003399"><SPAN style="FONT-SIZE: 9pt">- Խ ܿ (include) html 
 մϴ.<BR>- body, head  ±״ ⿡    켱 óմϴ.<BR></SPAN></FONT><FONT color=blue><SPAN style="FONT-SIZE: 9pt"><INPUT size="64" name="include_up" value="<?php echo $admin_data[include_top]?>" maxlength="255"></SPAN></FONT></P></TD></TR>

<TR><TD width="146" height=58 bgcolor="#F4F4F4">
<P align=center><FONT color=black><SPAN style="FONT-SIZE: 9pt">Խ ϴ 
</SPAN></FONT></P></TD>
<TD width="501" height=58 bgcolor="#FAFAFA">
<P><FONT color="#003399"><SPAN style="FONT-SIZE: 9pt">- Խ ϴܿ (include) html 
 մϴ.<BR></SPAN></FONT><FONT color=blue><SPAN style="FONT-SIZE: 9pt"><INPUT size="64" name="include_bt" value="<?php echo $admin_data[include_bottom]?>" maxlength="255"></SPAN></FONT></P></TD></TR>

<TR><TD width="146" height=58 bgcolor="#F4F4F4">
<P align=center><FONT color=black><SPAN style="FONT-SIZE: 9pt">Խ ŸƲ</SPAN></FONT></P></TD>
<TD width="501" height=58 bgcolor="#FAFAFA">
<P><FONT color="#003399"><SPAN style="FONT-SIZE: 9pt">-   ǥٿ ǥõ ؽƮԴϴ.<BR>
- ƹ͵ Է ø ⺻ մϴ (EtchiBoard 1.0 - [])<br>
</SPAN></FONT><FONT color=blue><SPAN style="FONT-SIZE: 9pt"><INPUT size="32" name="titlebar" value="<?php echo $admin_data[titlebar]?>" maxlength="255"></SPAN></FONT></P></TD></TR>

<TR><TD width="146" height=58 bgcolor="#F4F4F4">
<P align=center><FONT color=black><SPAN style="FONT-SIZE: 9pt">׸ ũ </SPAN></FONT></P></TD>
<TD width="501" height=58 bgcolor="#FAFAFA">
<P><FONT color="#003399"><SPAN style="FONT-SIZE: 9pt">- ׸ (width)ũⰡ Ʒ ġ  ڵ Ʒ ũ ¡ մϴ.<BR>
- 0 ¡  ʽϴ. ( - ¡ ׸   ֽϴ.)</SPAN></FONT><FONT color=blue><SPAN style="FONT-SIZE: 9pt">
<br>
<INPUT style="TEXT-ALIGN: center" size=14 name="width_max" value="<?php echo $admin_data[width_max]?>"><font color=black>ȼ ̻  ũ  ġ  (/  )</font></SPAN></FONT></P></TD></TR>

<TR><TD width="146" height=58 bgcolor="#F4F4F4">
<P align=center><FONT color=black><SPAN style="FONT-SIZE: 9pt">ڵ ũ </SPAN></FONT></P></TD>
<TD width="501" height=58 bgcolor="#FAFAFA">
<P><FONT color="#003399"><SPAN style="FONT-SIZE: 9pt">- Խù ο ִ Ʈ ּҸ ڵ ũ óִ Դϴ.<BR></SPAN></FONT>
<SPAN style="FONT-SIZE: 9pt">
<INPUT type=radio name="autolink" value="t" <?php echo $autolink[on]?>>&nbsp;
<INPUT type=radio name="autolink" value="f" <?php echo $autolink[off]?>> </SPAN>
</font></P></TD></TR>

<TR><TD width="146" height=58 bgcolor="#F4F4F4">
<P align=center><FONT color=black><SPAN style="FONT-SIZE: 9pt"> ߺüũ</SPAN></FONT></P></TD>
<TD width="501" height=58 bgcolor="#FAFAFA">
<P><FONT color="#003399">
<SPAN style="FONT-SIZE: 9pt">
- ÷ε ׸ md5 Ͽ ̹ ö  ִ ׸ ˻ ݴϴ.<BR>
- Խǿ ణ  ϰ   ֽϴ. ( ۼ)</SPAN><br>
</FONT>
<SPAN style="FONT-SIZE: 9pt">
<INPUT type=radio name="backdrum" value="t" <?php echo $backdrum[on]?>>&nbsp;
<INPUT type=radio name="backdrum" value="f" <?php echo $backdrum[off]?>> </SPAN>
</font></P></TD></TR>

<!--
<TR><TD width="146" height=58 bgcolor="#F4F4F4">
<P align=center><FONT color=black><SPAN style="FONT-SIZE: 9pt">Խù  Ѱġ</SPAN></FONT></P></TD>
<TD width="501" height=58 bgcolor="#FAFAFA">
<P><FONT color="#003399"><SPAN style="FONT-SIZE: 9pt">-  ġ   Խù   մϴ.<BR>
- 0 Դϴ (Խù   մϴ)</SPAN></FONT><FONT color=blue><SPAN style="FONT-SIZE: 9pt">
<br>
<INPUT style="TEXT-ALIGN: center" size=14 value="0" name="article_max" value="<?php echo $admin_data[article_max]?>" readonly><font color=black> </font></SPAN></FONT></P></TD></TR>
-->

<TR><TD width="146" height=30 bgcolor="#F4F4F4">
<P align=center><FONT color=black><SPAN style="FONT-SIZE: 9pt">ý </SPAN></FONT></P></TD>
<TD width="501" height=30 bgcolor="#FAFAFA">
<P><FONT color="#003399"><SPAN style="FONT-SIZE: 9pt"><a href="javascript:show_sysinfo();">[⸦ ŬϽø  ý  ǥմϴ]</a></SPAN></FONT></P></TD></TR>

</table>
</td></tr>
</table>

<P align=center><INPUT accessKey=s type=button value=" (Alt+S)" name=sendvalue onclick="submit_admin()"> 
<INPUT accessKey=r type=reset value="ٽ ۼ(Alt+R)" name=reset></P>
</form>

</body>
</html>

<?php
 }
?>
